******************************
The sherpa.models.model module
******************************

.. currentmodule:: sherpa.models.model

.. automodule:: sherpa.models.model

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      Model
      ArithmeticConstantModel
      ArithmeticFunctionModel
      ArithmeticModel
      CompositeModel
      BinaryOpModel
      MultigridSumModel
      NestedModel
      RegriddableModel
      RegriddableModel1D
      RegriddableModel2D
      SimulFitModel
      UnaryOpModel

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      modelCacher
      modelCacher1d

Class Inheritance Diagram
=========================

.. inheritance-diagram:: Model ArithmeticConstantModel ArithmeticFunctionModel ArithmeticModel CompositeModel BinaryOpModel MultigridSumModel NestedModel RegriddableModel RegriddableModel1D RegriddableModel2D SimulFitModel UnaryOpModel
   :parts: 1
